delegates Package
=================

:mod:`delegates` Package
------------------------

.. automodule:: camelot.view.controls.delegates
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`booldelegate` Module
--------------------------

.. automodule:: camelot.view.controls.delegates.booldelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`chartdelegate` Module
---------------------------

.. automodule:: camelot.view.controls.delegates.chartdelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`codedelegate` Module
--------------------------

.. automodule:: camelot.view.controls.delegates.codedelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`colordelegate` Module
---------------------------

.. automodule:: camelot.view.controls.delegates.colordelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`coloredfloatdelegate` Module
----------------------------------

.. automodule:: camelot.view.controls.delegates.coloredfloatdelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`comboboxdelegate` Module
------------------------------

.. automodule:: camelot.view.controls.delegates.comboboxdelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`currencydelegate` Module
------------------------------

.. automodule:: camelot.view.controls.delegates.currencydelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`customdelegate` Module
----------------------------

.. automodule:: camelot.view.controls.delegates.customdelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`datedelegate` Module
--------------------------

.. automodule:: camelot.view.controls.delegates.datedelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`datetimedelegate` Module
------------------------------

.. automodule:: camelot.view.controls.delegates.datetimedelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`delegatemanager` Module
-----------------------------

.. automodule:: camelot.view.controls.delegates.delegatemanager
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`enumerationdelegate` Module
---------------------------------

.. automodule:: camelot.view.controls.delegates.enumerationdelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`filedelegate` Module
--------------------------

.. automodule:: camelot.view.controls.delegates.filedelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`floatdelegate` Module
---------------------------

.. automodule:: camelot.view.controls.delegates.floatdelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`imagedelegate` Module
---------------------------

.. automodule:: camelot.view.controls.delegates.imagedelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`integerdelegate` Module
-----------------------------

.. automodule:: camelot.view.controls.delegates.integerdelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`intervalsdelegate` Module
-------------------------------

.. automodule:: camelot.view.controls.delegates.intervalsdelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`labeldelegate` Module
---------------------------

.. automodule:: camelot.view.controls.delegates.labeldelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`languagedelegate` Module
------------------------------

.. automodule:: camelot.view.controls.delegates.languagedelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`localfiledelegate` Module
-------------------------------

.. automodule:: camelot.view.controls.delegates.localfiledelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`many2onedelegate` Module
------------------------------

.. automodule:: camelot.view.controls.delegates.many2onedelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`manytomanydelegate` Module
--------------------------------

.. automodule:: camelot.view.controls.delegates.manytomanydelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`manytoonechoicesdelegate` Module
--------------------------------------

.. automodule:: camelot.view.controls.delegates.manytoonechoicesdelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`monthsdelegate` Module
----------------------------

.. automodule:: camelot.view.controls.delegates.monthsdelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`notedelegate` Module
--------------------------

.. automodule:: camelot.view.controls.delegates.notedelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`one2manydelegate` Module
------------------------------

.. automodule:: camelot.view.controls.delegates.one2manydelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`plaintextdelegate` Module
-------------------------------

.. automodule:: camelot.view.controls.delegates.plaintextdelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`richtextdelegate` Module
------------------------------

.. automodule:: camelot.view.controls.delegates.richtextdelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`smileydelegate` Module
----------------------------

.. automodule:: camelot.view.controls.delegates.smileydelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stardelegate` Module
--------------------------

.. automodule:: camelot.view.controls.delegates.stardelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`texteditdelegate` Module
------------------------------

.. automodule:: camelot.view.controls.delegates.texteditdelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`timedelegate` Module
--------------------------

.. automodule:: camelot.view.controls.delegates.timedelegate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`virtualaddressdelegate` Module
------------------------------------

.. automodule:: camelot.view.controls.delegates.virtualaddressdelegate
    :members:
    :undoc-members:
    :show-inheritance:

